@@ -1,6 +1,6 @@
 # Orca
 #
-# Copyright 2006 Sun Microsystems Inc.
+# Copyright 2006-2008 Sun Microsystems Inc.
 #
 # This library is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Library General Public
@@ -14,21 +14,21 @@
 #
 # You should have received a copy of the GNU Library General Public
 # License along with this library; if not, write to the
-# Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-# Boston, MA 02111-1307, USA.
+# Free Software Foundation, Inc., Franklin Street, Fifth Floor,
+# Boston MA  02110-1301 USA.
 
 """Holds platform-specific settings.
 """
 
-__id__        = "$Id: platform.py.in,v 1.2 2006/06/10 00:54:47 wwalker Exp $"
-__version__   = "$Revision: 1.2 $"
-__date__      = "$Date: 2006/06/10 00:54:47 $"
-__copyright__ = "Copyright (c) 2005-2006 Sun Microsystems Inc."
+__id__        = "$Id: platform.py.in 4221 2008-09-15 08:11:23Z wwalker $"
+__version__   = "$Revision: 4221 $"
+__date__      = "$Date: 2008-09-15 04:11:23 -0400 (Mon, 15 Sep 2008) $"
+__copyright__ = "Copyright (c) 2005-2008 Sun Microsystems Inc."
 __license__   = "LGPL"
 
 # $ORCA_MAJOR_VERSION.$ORCA_MINOR_VERSION.$ORCA_MICRO_VERSION
 #
-version     = "2.20.2"
+version     = "2.24.3"
 
 # "--prefix" parameter used when configuring the build.
 #
